package
Version:
v0.0.0-...-609bd80
Opens a new window with list of versions in this module.
Published: Mar 11, 2026
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type ExtendedSpec struct {
swag.Spec
Servers []struct {
URL string `json:"url"`
Description string `json:"description,omitempty"`
} `json:"servers,omitempty"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.