migrator

package
v0.0.0-...-609bd80 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 11, 2026 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Migrate

func Migrate() error

Migrate runs every migration specified in the getMigrations function. It should be run as early as possible in the program, and should never be called again.

Types

This section is empty.

Jump to