status_update

package
v0.0.0-...-609bd80 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 11, 2026 License: MIT Imports: 22 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func DeploymentEventListener

func DeploymentEventListener(ctx context.Context) error

func DeploymentStatusFetcher

func DeploymentStatusFetcher() error

func DeploymentStatusListener

func DeploymentStatusListener(ctx context.Context) error

func GpuClaimStatusListener

func GpuClaimStatusListener(ctx context.Context) error

func Setup

func Setup(ctx context.Context)

Setup starts the status updaters. Status updaters are workers that listen for status updates from external services and update the database accordingly.

func VmStatusFetcher

func VmStatusFetcher() error

func VmStatusListener

func VmStatusListener(ctx context.Context) error

Types

This section is empty.

Jump to