synchronize

package
v0.0.0-...-609bd80 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 11, 2026 License: MIT Imports: 17 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GpuLeaseSynchronizer

func GpuLeaseSynchronizer() error

func GpuSynchronizer

func GpuSynchronizer() error

GpuSynchronizer synchronizes the GPUs in the database with the sys-api page. Whenever a GPU is added or removed from a machine, the sys-api is updated, and this worker will synchronize the database with the sys-api

func Setup

func Setup(ctx context.Context)

Setup starts the synchronizers. Synchronizers are workers that periodically synchronize resources, such as GPUs.

Types

This section is empty.

Jump to