routers

package
v0.0.0-...-609bd80 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 11, 2026 License: MIT Imports: 23 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CorsAllowAll

func CorsAllowAll() gin.HandlerFunc

CorsAllowAll is a middleware that allows all origins

func HandleRoute

func HandleRoute(engine *gin.RouterGroup, method, path string, handler gin.HandlerFunc, middleware []gin.HandlerFunc)

HandleRoute registers a route with the given method, path, handler and middleware

func NewRouter

func NewRouter() *gin.Engine

NewRouter creates a new router It registers all routes and middlewares

Types

This section is empty.

Directories

Path Synopsis
api
v2

Jump to