Documentation
¶
Index ¶
- func DeploymentEventListener(ctx context.Context) error
- func DeploymentStatusFetcher() error
- func DeploymentStatusListener(ctx context.Context) error
- func GpuClaimStatusListener(ctx context.Context) error
- func Setup(ctx context.Context)
- func VmStatusFetcher() error
- func VmStatusListener(ctx context.Context) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DeploymentEventListener ¶
func DeploymentStatusFetcher ¶
func DeploymentStatusFetcher() error
func GpuClaimStatusListener ¶
func Setup ¶
Setup starts the status updaters. Status updaters are workers that listen for status updates from external services and update the database accordingly.
func VmStatusFetcher ¶
func VmStatusFetcher() error
func VmStatusListener ¶
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.