Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GpuLeaseSynchronizer ¶
func GpuLeaseSynchronizer() error
func GpuSynchronizer ¶
func GpuSynchronizer() error
GpuSynchronizer synchronizes the GPUs in the database with the sys-api page. Whenever a GPU is added or removed from a machine, the sys-api is updated, and this worker will synchronize the database with the sys-api
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.